// Copyright (c) 2022-2023 VMware Carbon Black, all rights reserved

package messagecode

//go:generate go run golang.org/x/tools/cmd/stringer -type=MessageCode

type MessageCode int

// NOTE: Changes here should also be reflected in `test/functional/suites/lib/models/enumerations.py`

//goland:noinspection GoSnakeCaseUsage
const (
	UNKNOWN                             MessageCode = iota
	REQ_DEVICE_FORENSICS                MessageCode = 0x000B // Device forensics notification
	RESP_DEVICE_FORENSICS               MessageCode = 0x000C // Device forensics notification response
	REQ_REGISTER_CONTROL                MessageCode = 0x1001 // Registration request
	RESP_REGISTER_CONTROL               MessageCode = 0x1002 // Registration response
	REQ_REGISTRATION_CODE               MessageCode = 0x1003 // Registration code request
	RESP_REGISTRATION_CODE              MessageCode = 0x1004 // Registration code response
	REQ_DEREGISTER                      MessageCode = 0x1017 // Deregister request
	RESP_DEREGISTER                     MessageCode = 0x1018 // Deregister response
	REQ_DOMAIN_CHECK                    MessageCode = 0x1019 // Domain Check request
	RESP_DOMAIN_CHECK                   MessageCode = 0x101A // Domain Check response
	REQ_VDI_REGISTRATION                MessageCode = 0x101B // VDI registration request
	RESP_VDI_REGISTRATION               MessageCode = 0x101C // VDI registration response
	REQ_REPUTATION                      MessageCode = 0x2005 // Reputation request
	RESP_REPUTATION                     MessageCode = 0x2006 // Reputation response
	REQ_IOS_DEVICE_STATUS               MessageCode = 0x1FFB // Device status request
	RESP_IOS_DEVICE_STATUS              MessageCode = 0x1FFC // Device status response
	REQ_ANDROID_DEVICE_STATUS           MessageCode = 0x1FFF // Android device status request
	RESP_ANDROID_DEVICE_STATUS          MessageCode = 0x2000 // Android device status response
	REQ_WINOSX_DEVICE_STATUS            MessageCode = 0x2001 // Windows/OSX device status request
	RESP_WINOSX_DEVICE_STATUS           MessageCode = 0x2002 // Windows/OSX device status response
	REQ_POLICY                          MessageCode = 0x2003 // Policy request
	RESP_POLICY                         MessageCode = 0x2004 // Policy response
	REQ_ANDROID_APPINFO                 MessageCode = 0x2007 // Android App Info Notification
	RESP_ANDROID_APPINFO                MessageCode = 0x2008 // Android App Info response
	REQ_DEVICE_QUALIFIERS               MessageCode = 0x2009 // Device Qualifiers notification
	RESP_DEVICE_QUALIFIERS              MessageCode = 0x200A // Device Qualifiers response
	REQ_CONFIGURATION                   MessageCode = 0x200B // Configuration request
	RESP_CONFIGURATION                  MessageCode = 0x200C // Configuration response
	REQ_FILE_BEHAVIOR                   MessageCode = 0x2010 // File Behavior Notification
	RESP_FILE_BEHAVIOR                  MessageCode = 0x2011 // File behavior response
	REQ_DATA_ACCESS_BEHAVIOR            MessageCode = 0x2012 // Data Access Behavior Notification
	RESP_DATA_ACCESS_BEHAVIOR           MessageCode = 0x2013 // Data access behavior response
	REQ_NETWORK_BEHAVIOR                MessageCode = 0x2014 // Network Behavior Notification
	RESP_NETWORK_BEHAVIOR               MessageCode = 0x2015 // File behavior response
	REQ_CREATE_PROCESS_BEHAVIOR         MessageCode = 0x2016 // Process Create Behavior Notification
	RESP_CREATE_PROCESS_BEHAVIOR        MessageCode = 0x2017 // Create process behavior response
	REQ_API_CALL_BEHAVIOR               MessageCode = 0x2018 // API Call Behavior Notification
	RESP_API_CALL_BEHAVIOR              MessageCode = 0x2019 // API Call Behavior response
	REQ_REGISTRY_ACCESS_BEHAVIOR        MessageCode = 0x201A // Registry Access Behavior request
	RESP_REGISTRY_ACCESS_BEHAVIOR       MessageCode = 0x201B // Registry Access Behavior response
	REQ_HELLO                           MessageCode = 0x201C // Hello Message
	RESP_HELLO                          MessageCode = 0x201D // Hello response
	REQ_NETWORK_STATUS                  MessageCode = 0x201E // Network Status Request
	RESP_NETWORK_STATUS                 MessageCode = 0x201F // Network Status Response
	REQ_NEWS                            MessageCode = 0x2020 // News feed request
	RESP_NEWS                           MessageCode = 0x2021 // News feed response
	REQ_NEWSACK                         MessageCode = 0x2022 // News ack request
	RESP_NEWSACK                        MessageCode = 0x2023 // News ack response
	REQ_ACTION_NOTIFICATION             MessageCode = 0x2024 // Action notification request
	RESP_ACTION_NOTIFICATION            MessageCode = 0x2025 // Action notification response
	REQ_HASH_EXECUTE_BEHAVIOR           MessageCode = 0x2026 // Hash execute behavior request
	RESP_HASH_EXECUTE_BEHAVIOR          MessageCode = 0x2027 // Hash execute behavior response
	REQ_FILE_DELETE_BEHAVIOR            MessageCode = 0x2028 // File delete behavior request
	RESP_FILE_DELETE_BEHAVIOR           MessageCode = 0x2029 // File delete behavior response
	REQ_FILE_UPLOAD                     MessageCode = 0x202A // File upload request
	RESP_FILE_UPLOAD                    MessageCode = 0x202B // File upload response
	REQ_CONFER_FILE_UPLOAD              MessageCode = 0x202C // File upload request
	RESP_CONFER_FILE_UPLOAD             MessageCode = 0x202D // File upload response
	REQ_HASH_LIST_REFRESH               MessageCode = 0x202E // Hash list refresh request
	RESP_HASH_LIST_REFRESH              MessageCode = 0x202F // Hash list refresh response
	REQ_GET_HASH_UPLOAD_LIST            MessageCode = 0x2030 // Get Hash Upload List request
	RESP_GET_HASH_UPLOAD_LIST           MessageCode = 0x2031 // Get Hash Upload List response
	REQ_UPLOAD_HASH                     MessageCode = 0x2032 // Upload Hash
	RESP_UPLOAD_HASH                    MessageCode = 0x2033 // Get Hash Upload List response
	REQ_GET_SOFTWARE_UPGRADE            MessageCode = 0x2034 // Get Software Upgrade
	RESP_GET_SOFTWARE_UPGRADE           MessageCode = 0x2035 // Get Software Upgrade response
	REQ_GET_SOFTWARE_PATCH              MessageCode = 0x2036 // Get Software Patch
	RESP_GET_SOFTWARE_PATCH             MessageCode = 0x2037 // Get Software Patch response
	REQ_GET_YARA_AV_SIGNATURES          MessageCode = 0x2038 // Get Yara AV Signatures
	RESP_GET_YARA_AV_SINGATURES         MessageCode = 0x2039 // Get Yara AV Signatures response
	REQ_GET_YARA_NETWORK_SIGNATURES     MessageCode = 0x203A // Get Yara Network Signatures
	RESP_GET_YARA_NETWORKAV_SINGATURES  MessageCode = 0x203B // Get Yara AV Network response
	REQ_GET_YARA_PE_HEADER_SIGNATURES   MessageCode = 0x203C // Get Yara PE Header Signatures
	RESP_GET_YARA_PE_HEADER_SIGNATURES  MessageCode = 0x203D // Get Yara PE Header Signatures response
	REQ_GET_IP_BLOCK_LIST               MessageCode = 0x203E // Get IP Block List
	RESP_GET_IP_BLOCK_LIST              MessageCode = 0x203F // Get IP Block List response
	REQ_GET_IP_FORENSICS_LIST           MessageCode = 0x2040 // Get IP Forensics List
	RESP_GET_IP_FORENSICS_LIST          MessageCode = 0x2041 // Get IP Block Forensics response
	REQ_GET_HASH_FORENSICS_LIST         MessageCode = 0x2042 // Get Hash Forensics List
	RESP_GET_HASH_FORENSICS_LIST        MessageCode = 0x2043 // Get Hash Forensics response
	REQ_GET_HASH_DELETE_LIST            MessageCode = 0x2044 // Get Onetime Hash Delete List request
	RESP_GET_HASH_DELETE_LIST           MessageCode = 0x2045 // Get Onetime Hash Delete response response
	REQ_GET_PERMANENT_HASH_DELETE_LIST  MessageCode = 0x2046 // Get Permanent Hash Delete List request
	RESP_GET_PERMANENT_HASH_DELETE_LIST MessageCode = 0x2047 // Get Permanent Hash Delete response response
	REQ_SEND_AD_ASSIGNMENTS             MessageCode = 0x204A // Send Active Directory assignments
	RESP_SEND_AD_ASSIGNMENTS            MessageCode = 0x204B // Response to Send Active Directory assignments request
	REQ_HASH_UPLOAD_STATUS              MessageCode = 0x204C // Status of request to upload a hash sample
	RESP_HASH_UPLOAD_STATUS             MessageCode = 0x204D // Response to Status of request to upload a hash sample
	REQ_AV_ANALYSIS_UPLOAD_STATUS       MessageCode = 0x204E // Av analysis upload status
	RESP_AV_ANALYSIS_UPLOAD_STATUS      MessageCode = 0x204F // Response to Av analysis upload status
	REQ_PHISHING_CONFIG                 MessageCode = 0x2050 // Phishing configure request
	RESP_PHISHING_CONFIG                MessageCode = 0x2051 // Phishing configure response
	REQ_PHISHING_FILE                   MessageCode = 0x2052 // Phishing file request
	RESP_PHISHING_FILE                  MessageCode = 0x2053 // Phishing file response
	REQ_PHISHING_ALERT_BEHAVIOR         MessageCode = 0x2054 // Phishing alert behavior request msg
	RESP_PHISHING_ALERT_BEHAVIOR        MessageCode = 0x2055 // Phishing alert behavior response
	REQ_CERTIFICATE_UPLOAD              MessageCode = 0x2056 // Executable certificate upload request
	RESP_CERTIFICATE_UPLOAD             MessageCode = 0x2057 // Executable certificate upload response
	REQ_SCAN_ACTION_NOTIFICATION        MessageCode = 0x2058 // Scan action notification request
	RESP_SCAN_ACTION_NOTIFICATION       MessageCode = 0x2059 // Scan action notification response
	REQ_ALARM_NOTIFICATION              MessageCode = 0x2071 // Alarm notification
	RESP_ALARM_NOTIFICATION             MessageCode = 0x2072 // Alarm response
	REQ_CONFIGURATION_V2                MessageCode = 0x2074 // Configuration v2 request
	RESP_CONFIGURATION_V2               MessageCode = 0x2075 // Configuration v2 response
	REQ_SENSOR_ACTION                   MessageCode = 0x2076 // Sensor action request
	RESP_SENSOR_ACTION                  MessageCode = 0x2077 // Sensor action response
	REQ_SENSOR_ACTION_REPORT            MessageCode = 0x2078 // Sensor action report request
	RESP_SENSOR_ACTION_REPORT           MessageCode = 0x2079 // Sensor action report response
	REQ_LIVE_RESPONSE_COMMAND           MessageCode = 0x2080 // Live Response Command Request
	RESP_LIVE_RESPONSE_COMMAND          MessageCode = 0x2081 // Live Response Command Response
	REQ_RANSOMWARE_PAYLOAD              MessageCode = 0x2090 // Ransomware payload request
	RESP_RANSOMWARE_PAYLOAD             MessageCode = 0x2091 // Ransomware payload response
	REQ_APC_UPLOAD                      MessageCode = 0x20A0 // APC upload request
	RESP_APC_UPLOAD                     MessageCode = 0x20A1 // APC upload response
	REQ_UNINSTALL_CODE                  MessageCode = 0x20B0 // Uninstall Code request
	RESP_UNINSTALL_CODE                 MessageCode = 0x20B1 // Uninstall Code response
	REQ_META_DATA_UDPATE_CODE           MessageCode = 0x20B2 // Meta Data Update request
	RES_META_DATA_UDPATE_CODE           MessageCode = 0x20B3 // Meta Data Update response
	REQ_BULK_BEHAVIOR                   MessageCode = 0x20B6 // Bulk behavior request
	RESP_BULK_BEHAVIOR                  MessageCode = 0x20B7 // Bulk behavior response
	REQ_BULK_REPUTATION                 MessageCode = 0x20C2 // Bulk reputation request    ***NOT IN CONFLUENCE YET!
	RESP_BULK_REPUTATION                MessageCode = 0x20C3 // Bulk reputation response   ***NOT IN CONFLUENCE YET!
	REQ_ASYNC_REPUTATION                MessageCode = 0x20C4 // Async reputation request   ***NOT IN CONFLUENCE YET!
	RESP_ASYNC_REPUTATION               MessageCode = 0x20C5 // Async reputation response  ***NOT IN CONFLUENCE YET!
	REQ_PSCR_EVENT_BATCH                MessageCode = 0x20D0 // PSC batch event request
	RESP_PSCR_EVENT_BATCH               MessageCode = 0x20D1 // PSC batch event response
	REQ_NEW                             MessageCode = 0x20d2 // Deprecated; retained for backwards compatibility
	RESP_NEW                            MessageCode = 0x20d3 // Deprecated; retained for backwards compatibility
)

//goland:noinspection GoSnakeCaseUsage
var MESSAGE_CODE_STRINGS = getMessageCodeStrings()

func getMessageCodeStrings() map[string]MessageCode {
	messageCodeStrings := make(map[string]MessageCode)
	for key := range _MessageCode_map {
		value := _MessageCode_map[key]
		messageCodeStrings[value] = key
	}
	return messageCodeStrings
}
